@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2020-2021 -- leonerd@leonerd.org.uk
 
-package Object::Pad::MOP::Class 0.41;
+package Object::Pad::MOP::Class 0.42;
 
 use v5.14;
 use warnings;
@@ -159,6 +159,15 @@ Returns an instance of L<Object::Pad::MOP::Slot> to represent it.
 Returns an instance of L<Object::Pad::MOP::Slot> to represent the slot of the
 given name, if one exists. If not an exception is thrown.
 
+=head2 slots
+
+   @metaslots = $metaclass->slots
+
+I<Since version 0.42.>
+
+Returns a list of L<Object::Pad::MOP::Slot> instances to represent all the
+slots of the class. This list may be empty.
+
 =cut
 
 =head1 AUTHOR
